==> XDE_1.2.0.zip: XDE/doc/XdeParameterClass.R <==
###################################################
### chunk number 1: 
###################################################
options(width=60)


###################################################
### chunk number 2: params
###################################################
library(XDE)
data(expressionSetList)
xlist <- expressionSetList
params <- new("XdeParameter", esetList=xlist, phenotypeLabel="adenoVsquamous")
params


###################################################
### chunk number 3: firstMcmc
###################################################
initialValues <- firstMcmc(params)
str(initialValues)


###################################################
### chunk number 4: specifiedInitialValues
###################################################
params@specifiedInitialValues


###################################################
### chunk number 5: hyperparameters
###################################################
hyperparameters(params)


###################################################
### chunk number 6: hyperparamReplace eval=FALSE
###################################################
## hyperparameters(params)["alpha.a"] <- 1


###################################################
### chunk number 7: tuning
###################################################
tuning(params)


###################################################
### chunk number 8: changeEpsilon
###################################################
tuning(params)["a"] <- tuning(params)["a"]*0.5


###################################################
### chunk number 9: updates
###################################################
updates(params)


###################################################
### chunk number 10: conjugacy eval=FALSE
###################################################
## firstMcmc(params)$B <- rep(1,3)
## updates(params)["b"] <- 0


###################################################
### chunk number 11: independence eval=FALSE
###################################################
## firstMcmc(params)$B <- rep(0, 3)
## updates(params)["b"] <- 0


###################################################
### chunk number 12: blockUpdates eval=FALSE
###################################################
## updates(params)["rAndC2"] <- 3


###################################################
### chunk number 13: output
###################################################
output(params)


###################################################
### chunk number 14: differentPath eval=FALSE
###################################################
## directory(params) <- "logFiles"


###################################################
### chunk number 15: burnin
###################################################
burnin(params) <- TRUE
iterations(params) <- 5


###################################################
### chunk number 16: burnin2
###################################################
output(params)[2:22] <- rep(1, 21)
output(params)
burnin(params) <- TRUE
output(params)


###################################################
### chunk number 17: burnin3
###################################################
##Specify a thin of 1 and save none of the parameters
output(params)[2:22] <- rep(0, 21)
output(params)
burnin(params) <- FALSE
output(params)


###################################################
### chunk number 18: doNotSaveHugeChains
###################################################
burnin(params) <- FALSE
output(params)[c("nu", "DDelta", "delta", "probDelta", "sigma2", "phi")] <- 0
output(params)


###################################################
### chunk number 19: 
###################################################
toLatex(sessionInfo())

==> XDE_1.10.0.zip: XDE/doc/XdeParameterClass.R <==
###################################################
### chunk number 1: 
###################################################
#line 44 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
options(width=60)


###################################################
### chunk number 2: params
###################################################
#line 333 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
library(XDE)
data(expressionSetList)
xlist <- expressionSetList
params <- new("XdeParameter", esetList=xlist, phenotypeLabel="adenoVsquamous")
params


###################################################
### chunk number 3: firstMcmc
###################################################
#line 345 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
initialValues <- firstMcmc(params)
str(initialValues)


###################################################
### chunk number 4: specifiedInitialValues
###################################################
#line 362 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
params@specifiedInitialValues


###################################################
### chunk number 5: hyperparameters
###################################################
#line 375 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
hyperparameters(params)


###################################################
### chunk number 6: hyperparamReplace eval=FALSE
###################################################
## #line 408 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
## hyperparameters(params)["alpha.a"] <- 1


###################################################
### chunk number 7: tuning
###################################################
#line 418 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
tuning(params)


###################################################
### chunk number 8: changeEpsilon
###################################################
#line 428 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
tuning(params)["a"] <- tuning(params)["a"]*0.5


###################################################
### chunk number 9: updates
###################################################
#line 438 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
updates(params)


###################################################
### chunk number 10: conjugacy eval=FALSE
###################################################
## #line 447 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
## firstMcmc(params)$B <- rep(1,3)
## updates(params)["b"] <- 0


###################################################
### chunk number 11: independence eval=FALSE
###################################################
## #line 455 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
## firstMcmc(params)$B <- rep(0, 3)
## updates(params)["b"] <- 0


###################################################
### chunk number 12: blockUpdates eval=FALSE
###################################################
## #line 464 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
## updates(params)["rAndC2"] <- 3


###################################################
### chunk number 13: output
###################################################
#line 474 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
output(params)


###################################################
### chunk number 14: differentPath eval=FALSE
###################################################
## #line 487 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
## directory(params) <- "logFiles"


###################################################
### chunk number 15: burnin
###################################################
#line 503 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
burnin(params) <- TRUE
iterations(params) <- 5


###################################################
### chunk number 16: burnin2
###################################################
#line 509 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
output(params)[2:22] <- rep(1, 21)
output(params)
burnin(params) <- TRUE
output(params)


###################################################
### chunk number 17: burnin3
###################################################
#line 518 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
##Specify a thin of 1 and save none of the parameters
output(params)[2:22] <- rep(0, 21)
output(params)
burnin(params) <- FALSE
output(params)


###################################################
### chunk number 18: doNotSaveHugeChains
###################################################
#line 528 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
burnin(params) <- FALSE
output(params)[c("nu", "DDelta", "delta", "probDelta", "sigma2", "phi")] <- 0
output(params)


###################################################
### chunk number 19: 
###################################################
#line 539 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpoUWXHy/R.INSTALL3c4639bd/XDE/inst/doc/XdeParameterClass.Rnw"
toLatex(sessionInfo())
